@@ -351,6 +351,7 @@ class SpacerakeSDK:
         return resp.headers['location']
 
     # --- OSM ---
+
     async def search_geocode(self, query: str) -> List[Any]:
         return await self.__abstract_get(
             f'/api/v0/search/geocode',
@@ -358,3 +359,12 @@ class SpacerakeSDK:
             params={'query': query}
         )
 
+    async def search_geocode_reverse(self, lat: float, lon: float) -> Any:
+        return await self.__abstract_get(
+            f'/api/v0/search/geocode/reverse',
+            Any,
+            params={
+                'lat': lat,
+                'lon': lon
+            }
+        )
